@@ -20,11 +20,11 @@
  */
 
 import GObject from 'gi://GObject';
-import GeocodeGlib from 'gi://GeocodeGlib';
 
 import {Application} from './application.js';
 import {PlaceStore} from './placeStore.js';
 import {TransitOptions} from './transitOptions.js';
+import { Place } from './place.js';
 
 export class QueryPoint extends GObject.Object {
 
@@ -50,7 +50,7 @@ GObject.registerClass({
                                           '',
                                           GObject.ParamFlags.READABLE |
                                           GObject.ParamFlags.WRITABLE,
-                                          GeocodeGlib.Place)
+                                          Place)
     }
 }, QueryPoint);
 
@@ -141,8 +141,8 @@ export class RouteQuery extends GObject.Object {
         this.notify('points');
     }
 
-    constructor(args) {
-        super(args);
+    constructor(params) {
+        super(params);
         this._points = [];
         this._time = null;
         this._date = null;
@@ -170,10 +170,7 @@ export class RouteQuery extends GObject.Object {
         point.connect('notify::place', () => {
             let placeStore = Application.placeStore;
             if (point.place) {
-                if (!placeStore.exists(point.place, null)) {
-                    placeStore.addPlace(point.place,
-                                        PlaceStore.PlaceType.RECENT);
-                }
+                placeStore.addPlace(point.place);
             }
             this.notify('points');
             this._latest = point;
