@@ -19,6 +19,8 @@
  * Author: Marcus Lundblad <ml@dfupdate.se>
  */
 
+import gettext from 'gettext';
+
 import GWeather from 'gi://GWeather';
 import GLib from 'gi://GLib';
 import Shumate from 'gi://Shumate';
@@ -33,6 +35,8 @@ import * as Time from '../time.js';
 import {Itinerary, Leg, RouteType, Stop} from '../transitPlan.js';
 import * as Utils from '../utils.js';
 
+const _ = gettext.gettext;
+
 export class Motis2 {
     constructor(params) {
         this._baseUrl = GLib.getenv('MOTIS_BASE_URL') ?? params?.baseUrl;
@@ -169,12 +173,12 @@ export class Motis2 {
          * recalculate it for each stop
          */
         const departureTimezoneOffset =
-            this._getTimezoneOffset(departure / 1000,
+            this._getTimezoneOffset(departure,
                                     commonTz ??
                                     this._getTimezone(startPlace.location.latitude,
                                                       startPlace.location.longitude));
         const arrivalTimezoneOffset =
-            this._getTimezoneOffset(arrival / 1000,
+            this._getTimezoneOffset(arrival,
                                     commonTz ??
                                     this._getTimezone(destinationPlace.location.latitude,
                                                       destinationPlace.location.longitude));
@@ -209,13 +213,13 @@ export class Motis2 {
         const [departure,] = Time.parseTime(leg.startTime);
         const departureTimezoneOffset =
             commonTimezoneOffset ??
-            this._getTimezoneOffset(departure / 1000, this._getTimezone(leg.from.lat,
-                                                                        leg.from.lon));
+            this._getTimezoneOffset(departure, this._getTimezone(leg.from.lat,
+                                                                 leg.from.lon));
         const [arrival,] = Time.parseTime(leg.endTime);
         const arrivalTimezoneOffset =
             commonTimezoneOffset ??
-            this._getTimezoneOffset(arrival / 1000, this._getTimezone(leg.to.lat,
-                                                                      leg.to.lon));
+            this._getTimezoneOffset(arrival, this._getTimezone(leg.to.lat,
+                                                               leg.to.lon));
         const from = isFirst && !isTransit ? startPlace.name : leg.from.name;
         const to = isLast && !isTransit ? destinationPlace.name : leg.to.name;
 
@@ -293,7 +297,7 @@ export class Motis2 {
         const [arrival,] = Time.parseTime(stop.arrival);
         const timezoneOffset =
             commonTimezoneOffset ??
-            this._getTimezoneOffset(Math.max(arrival / 1000, departure / 1000),
+            this._getTimezoneOffset(Math.max(arrival, departure),
                                     this._getTimezone(stop.lat, stop.lon));
 
         return new Stop({ name:                 stop.name,
@@ -335,6 +339,10 @@ export class Motis2 {
         switch (step.relativeDirection) {
             case 'DEPART':
             case 'STAIRS':
+                return [TurnPoint.Type.STAIRS,
+                        step.hasOwnProperty('toLevel') ?
+                        _("Take the stairs to level %s").format(step.toLevel) :
+                        _("Take the stairs")];
             case 'CONTINUE':
                 return [TurnPoint.Type.CONTINUE,
                         step.streetName ?
